%define tarname    shiboken
%define pyver_mod2 %(python3 -c "import sys; sys.stdout.write(sys.version[:3].replace('.','')+sys.abiflags)")
%define pyname     Shiboken

%define includevelname  %{name}-include-devel
%define cmakedevelname  %{name}-cmake-devel

%define verconflicts    1.2.2-9

Name:           shiboken
Version:        1.2.2
Release:        %mkrel 10
License:        GPLv2
Summary:        Creates the PySide bindings source files
Group:          Development/KDE and Qt
URL:            http://www.pyside.org
Source0:        http://download.qt-project.org/official_releases/pyside/%{name}-%{version}.tar.bz2
#Fix suffix names for python3 and search libs
Patch0:         shiboken-1.2.2-python3.5.patch
BuildRequires:  cmake
BuildRequires:  qt4-devel
BuildRequires:  python-devel
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(libxml-2.0)
Obsoletes:      generatorrunner < 0.6.17

%description
The Shiboken Generator (A.K.A. shiboken) is the plugin that creates the
PySide bindings source files from Qt headers and auxiliary files
(typesystems, global.h and glue files).

%files
%{_bindir}/%{name}
%{python_sitearch}/%{name}.so
%{_mandir}/man1/%{name}.1.xz

#------------------------------------------------------------------------------

%package -n python3-%{tarname}
Summary:        Creates the PySide bindings source files
Group:          Development/KDE and Qt
BuildRequires:  python3-devel

%description -n python3-%{tarname}
The Shiboken Generator (A.K.A. shiboken) is the plugin that creates the
PySide bindings source files from Qt headers and auxiliary files
(typesystems, global.h and glue files). This is the Python3 version.

%files -n python3-%{tarname}
%{_bindir}/%{tarname}-%{python3_version}
%{python3_sitearch}/%{tarname}.so
%{_mandir}/man1/%{tarname}-%{python3_version}.1.xz

#------------------------------------------------------------------------------

%define libmajor 1
%define libname %mklibname %{name} %{libmajor}

%package -n %{libname}
Summary:        Shiboken Generator core lib
Group:          System/Libraries
Obsoletes:      %{_lib}apiextractor0 < 0.10.11
Obsoletes:      %{_lib}genrunner0 < 0.6.17

%description -n %{libname}
Shiboken Generator core lib.

%files -n %{libname}
%{_libdir}/lib%{name}-python%{python2_version}.so.%{libmajor}*

#------------------------------------------------------------------------------

%define py3libname %mklibname python3-%{tarname} %{libmajor}

%package -n %{py3libname}
Summary:        Shiboken Generator core lib
Group:          System/Libraries

%description -n %{py3libname}
Shiboken Generator core lib. This is the Python3 version.

%files -n %{py3libname}
%{_libdir}/lib%{name}-python%{python3_version}.so.%{libmajor}*


#------------------------------------------------------------------------------

%package -n python3-%{tarname}-devel
Summary:        Development files for Shiboken Generator
Group:          Development/KDE and Qt
Requires:       %{py3libname} = %{version}
Requires:       python3-%{tarname} = %{version}
Requires:       %{includevelname} = %{version}-%{release}
Requires:       %{cmakedevelname} = %{version}-%{release}

%description -n python3-%{tarname}-devel
Development files for Shiboken Generator. This is the Python3 version.

%files -n python3-%{tarname}-devel
%{_libdir}/lib%{name}-python%{python3_version}.so
%{_libdir}/pkgconfig/%{tarname}-python%{python3_version}.pc
%{_libdir}/cmake/%{pyname}-%{version}/ShibokenConfig-python%{python3_version}.cmake

#------------------------------------------------------------------------------

%package devel
Summary:        Development files for Shiboken Generator
Group:          Development/KDE and Qt
Requires:       %{libname} = %{version}
Requires:       %{name} = %{version}
Requires:       %{includevelname} = %{version}-%{release}
Requires:       %{cmakedevelname} = %{version}-%{release}

Obsoletes:      %{_lib}apiextractor-devel < 0.10.11
Obsoletes:      generatorrunner-devel < 0.6.17

%description devel
Development files for Shiboken Generator.

%files devel
%{_libdir}/lib%{tarname}-python%{python2_version}.so
%{_libdir}/pkgconfig/%{tarname}.pc
%{_libdir}/cmake/%{pyname}-%{version}/ShibokenConfig-python%{python2_version}.cmake

#------------------------------------------------------------------------------


%package -n %{includevelname}
Summary:        Include files for Shiboken Generator
Group:          Development/KDE and Qt
Requires:       %{libname} = %{version}-%{release}
Requires:       %{name} = %{version}-%{release}
Conflicts:      %{name}-devel < %{verconflicts}
Conflicts:      python3-%{name}-devel < %{verconflicts}

%description -n %{includevelname}
Common include files for both the Python2 and Python3
development packages of the Shiboken Generator.

%files -n %{includevelname}
%{_includedir}/%{tarname}



%package -n %{cmakedevelname}
Summary:        Include files for Shiboken Generator
Group:          Development/KDE and Qt
Requires:       %{libname} = %{version}-%{release}
Requires:       %{name} = %{version}-%{release}
Conflicts:      %{name}-devel < %{verconflicts}
Conflicts:      python3-%{name}-devel < %{verconflicts}

%description -n %{cmakedevelname}
Common cmake files for both the Python2 and Python3
development packages of the Shiboken Generator.

%files -n %{cmakedevelname}
%{_libdir}/cmake/%{pyname}-%{version}/ShibokenConfig.cmake
%{_libdir}/cmake/%{pyname}-%{version}/ShibokenConfigVersion.cmake




%prep
%setup -qn %{name}-%{version}
%autopatch -p1
cp -a . %{py3dir}

%build
pushd %{py3dir}
%cmake -DUSE_PYTHON3=True
%make_build
popd

%cmake
%make_build

%install
pushd %{py3dir}
%make_install -C build
%__mv %{buildroot}%{_bindir}/%{tarname} %{buildroot}%{_bindir}/%{tarname}-%{python3_version}
%__mv %{buildroot}%{_mandir}/man1/%{tarname}.1 %{buildroot}%{_mandir}/man1/%{tarname}-%{python3_version}.1
%__mv %{buildroot}%{_libdir}/pkgconfig/%{tarname}.pc %{buildroot}%{_libdir}/pkgconfig/%{tarname}-python%{python3_version}.pc
popd

%make_install -C build



%changelog
* Sun Jun 18 2017 eatdirt <eatdirt> 1.2.2-10.mga6
+ Revision: 1107877
- Add explicit conflicts to actually fix mga5->mga6 upgrade

* Thu Jun 15 2017 eatdirt <eatdirt> 1.2.2-9.mga6
+ Revision: 1107771
- Fix non-standard cmake files + rename python3 pkgconfig file

* Thu Jun 15 2017 eatdirt <eatdirt> 1.2.2-8.mga6
+ Revision: 1107736
- Fixing conflicts killing mga5 upgrade and python3 packaging issues

* Wed Feb 17 2016 umeabot <umeabot> 1.2.2-7.mga6
+ Revision: 962809
- Mageia 6 Mass Rebuild

* Thu Oct 08 2015 tv <tv> 1.2.2-6.mga6
+ Revision: 887311
- use new python macros
- fix build with python 3.5

  + philippem <philippem>
    - rebuild for Python3.5

* Wed Oct 15 2014 umeabot <umeabot> 1.2.2-5.mga5
+ Revision: 743389
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.2.2-4.mga5
+ Revision: 730121
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.2.2-3.mga5
+ Revision: 689139
- Mageia 5 Mass Rebuild

* Mon Jun 02 2014 philippem <philippem> 1.2.2-2.mga5
+ Revision: 630675
- rebuild for Python3.4

* Wed May 14 2014 fwang <fwang> 1.2.2-1.mga5
+ Revision: 622688
- drop patch0
- drop patch0
- 1.2.2

* Fri Apr 18 2014 philippem <philippem> 1.2.1-3.mga5
+ Revision: 615790
- add Python3

  + akien <akien>
    - Rebuild for mga5

* Sat Oct 19 2013 umeabot <umeabot> 1.2.1-2.mga4
+ Revision: 533378
- Mageia 4 Mass Rebuild

* Thu Aug 29 2013 fwang <fwang> 1.2.1-1.mga4
+ Revision: 472835
- new version 1.2.1

* Mon Jul 15 2013 fwang <fwang> 1.2.0-1.mga4
+ Revision: 454660
- new version 1.2.0

* Mon Jan 14 2013 umeabot <umeabot> 1.1.2-2.mga3
+ Revision: 381969
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 01 2012 fwang <fwang> 1.1.2-1.mga3
+ Revision: 286921
- update file list
- new version 1.1.2

* Wed Jul 18 2012 fwang <fwang> 1.1.1-3.mga3
+ Revision: 272279
- obsoletes merged packages

* Wed Jul 18 2012 fwang <fwang> 1.1.1-2.mga3
+ Revision: 272270
- br xslt and xml2
- all the toolchain have been merged into one

* Sun Jun 03 2012 fwang <fwang> 1.1.1-1.mga3
+ Revision: 253519
- update file list
- new version 1.1.1

* Sat Jan 07 2012 fwang <fwang> 1.1.0-1.mga2
+ Revision: 192833
- new version 1.1.0

* Tue Dec 06 2011 fwang <fwang> 1.0.10-1.mga2
+ Revision: 177232
- new version 1.0.10

* Thu Oct 27 2011 fwang <fwang> 1.0.9-1.mga2
+ Revision: 158549
- new version 1.0.9

* Tue Oct 25 2011 fwang <fwang> 1.0.8-1.mga2
+ Revision: 157949
- new version 1.0.8

* Sun Sep 25 2011 fwang <fwang> 1.0.7-1.mga2
+ Revision: 147673
- new version 1.0.7
- new version 1.0.6
- new version 1.0.5

* Mon Jun 27 2011 fwang <fwang> 1.0.4-1.mga2
+ Revision: 114439
- new version 1.0.4

* Thu Mar 24 2011 boklm <boklm> 1.0.0-2.mga1
+ Revision: 76209
- rebuild for bug #497

* Mon Mar 07 2011 mikala <mikala> 1.0.0-1.mga1
+ Revision: 66185
- Update tarball to 1.0.0

* Sat Mar 05 2011 mikala <mikala> 1.0.0-0.rc1.1.mga1
+ Revision: 64966
- Drop BuildRoot
- imported package shiboken

